@@ -12,7 +12,7 @@ If you want to control type and mode of logger, use neaty.make_logger()
 factory.
 
 If you want to just start logging, use 'neaty.log', which creates global logger
-based on variables `NEATY`, `NEATY_DEBUG` and `NEATY_VERBOSE`.
+based on environment variables `NEATY`, `NEATY_DEBUG` and `NEATY_VERBOSE`.
 
 As a simplest possible example, consider following script:
 
